import { ZoomTransform } from 'd3-zoom';
import { IPosition, IRectangle } from '../../common';
import { INodeBase } from '../../models/node';
import { IEdgeBase } from '../../models/edge';
import { IGraph } from '../../models/graph';
import { Emitter } from '../../utils/emitter.utils';
import { IRenderer, IRendererSettings, RendererEvents as RE } from '../shared';
export declare class CanvasRenderer<N extends INodeBase, E extends IEdgeBase> extends Emitter<RE> implements IRenderer<N, E> {
    private readonly _context;
    width: number;
    height: number;
    private _settings;
    transform: ZoomTransform;
    private _isOriginCentered;
    private _isInitiallyRendered;
    private _throttleRender;
    constructor(context: CanvasRenderingContext2D, settings?: Partial<IRendererSettings>);
    get isInitiallyRendered(): boolean;
    getSettings(): IRendererSettings;
    setSettings(settings: Partial<IRendererSettings>): void;
    render(graph: IGraph<N, E>): void;
    private _render;
    private drawObjects;
    private drawObject;
    reset(): void;
    getFitZoomTransform(graph: IGraph<N, E>): ZoomTransform;
    getSimulationPosition(canvasPoint: IPosition): IPosition;
    /**
     * Returns the visible rectangle view in the simulation coordinates.
     *
     * @return {IRectangle} Visible view in the simulation coordinates
     */
    getSimulationViewRectangle(): IRectangle;
    translateOriginToCenter(): void;
}
