import { ZoomTransform } from 'd3-zoom';
import { Color, IPosition, IRectangle } from '../common';
import { INodeBase } from '../models/node';
import { IEdgeBase } from '../models/edge';
import { IGraph } from '../models/graph';
import { IEmitter } from '../utils/emitter.utils';
export declare enum RendererType {
    CANVAS = "canvas",
    WEBGL = "webgl"
}
export declare enum RenderEventType {
    RENDER_START = "render-start",
    RENDER_END = "render-end"
}
export interface IRendererSettings {
    fps: number;
    minZoom: number;
    maxZoom: number;
    fitZoomMargin: number;
    labelsIsEnabled: boolean;
    labelsOnEventIsEnabled: boolean;
    shadowIsEnabled: boolean;
    shadowOnEventIsEnabled: boolean;
    contextAlphaOnEvent: number;
    contextAlphaOnEventIsEnabled: boolean;
    backgroundColor: Color | string | null;
}
export interface IRendererSettingsInit extends IRendererSettings {
    type: RendererType;
}
export declare type RendererEvents = {
    [RenderEventType.RENDER_START]: undefined;
    [RenderEventType.RENDER_END]: {
        durationMs: number;
    };
};
export interface IRenderer<N extends INodeBase, E extends IEdgeBase> extends IEmitter<RendererEvents> {
    width: number;
    height: number;
    transform: ZoomTransform;
    get isInitiallyRendered(): boolean;
    getSettings(): IRendererSettings;
    setSettings(settings: Partial<IRendererSettings>): void;
    render(graph: IGraph<N, E>): void;
    reset(): void;
    getFitZoomTransform(graph: IGraph<N, E>): ZoomTransform;
    getSimulationPosition(canvasPoint: IPosition): IPosition;
    /**
     * Returns the visible rectangle view in the simulation coordinates.
     *
     * @return {IRectangle} Visible view in the simulation coordinates
     */
    getSimulationViewRectangle(): IRectangle;
    translateOriginToCenter(): void;
}
export declare const DEFAULT_RENDERER_SETTINGS: IRendererSettings;
export declare const DEFAULT_RENDERER_WIDTH = 640;
export declare const DEFAULT_RENDERER_HEIGHT = 480;
