/**
 * A key-value model that keeps an order of the elements by
 * the input sort function.
 *
 * Inspired by NgRx/EntityState: https://github.com/ngrx/platform
 */
export interface IEntityState<K, V> {
    getOne(id: K): V | undefined;
    getMany(ids: K[], options?: Partial<IEntityGetOptions<V>>): V[];
    getAll(options?: Partial<IEntityGetOptions<V>>): V[];
    setOne(entity: V): void;
    setMany(entities: V[]): void;
    removeMany(ids: K[]): void;
    removeAll(): void;
    sort(): void;
    size: number;
}
export interface IEntityDefinition<K, V> {
    getId: (entity: V) => K;
    sortBy?: (entity1: V, entity2: V) => number;
}
export interface IEntityGetOptions<V> {
    filterBy: (entity: V) => boolean;
}
export declare class EntityState<K, V> implements IEntityState<K, V> {
    private ids;
    private entityById;
    private getId;
    private sortBy?;
    constructor(definition: IEntityDefinition<K, V>);
    getOne(id: K): V | undefined;
    getMany(ids: K[], options?: Partial<IEntityGetOptions<V>>): V[];
    getAll(options?: Partial<IEntityGetOptions<V>>): V[];
    setOne(entity: V): void;
    setMany(entities: V[]): void;
    removeMany(ids: K[]): void;
    removeAll(): void;
    sort(): void;
    get size(): number;
}
