export const throttle = (fn, waitMs = 300) => {
    let isInThrottle = false;
    let lastTimer;
    let lastTimestamp = Date.now();
    return function () {
        // eslint-disable-next-line prefer-rest-params
        const args = arguments;
        const now = Date.now();
        if (!isInThrottle) {
            fn(...args);
            lastTimestamp = now;
            isInThrottle = true;
            return;
        }
        clearTimeout(lastTimer);
        const timerWaitMs = Math.max(waitMs - (now - lastTimestamp), 0);
        lastTimer = setTimeout(() => {
            if (now - lastTimestamp >= waitMs) {
                fn(...args);
                lastTimestamp = now;
            }
        }, timerWaitMs);
    };
};
//# sourceMappingURL=function.utils.js.map